@@ -4,6 +4,7 @@
 //
 
 use std::collections::HashMap;
+use std::iter;
 use std::process::Command;
 
 use chrono_humanize::HumanTime;
@@ -57,11 +58,15 @@ impl Show for HashMap<String, Vec<String>> {
 
 impl Show for Command {
     fn show(&self) -> String {
-        format!("{:?}", self).replace("\"", "")
+        let cmd = iter::once(self.get_program())
+            .chain(self.get_args())
+            .map(|elt| elt.to_string_lossy())
+            .format(" ");
+        format!("{}", cmd)
     }
 
     fn detailed_show(&self) -> String {
-        format!("             {:?}", self).replace("\"", "")
+        format!("             {}", self.show())
     }
 }
 
