@@ -84,4 +84,34 @@ mod tests {
         assert!(azure.get("AZURE_CLIENT_SECRET").is_some());
         assert!(azure.get("azure_client_secret").is_none());
     }
+
+    #[test]
+    fn azure_to_secret() {
+        let azure = AzureCredentials {
+            azure_tenant_id: String::from("tenant").into(),
+            azure_client_id: String::from("client").into(),
+            azure_client_secret: String::from("secret").into(),
+        };
+
+        let creds = json::to_value(azure).unwrap();
+        let mut creds = creds
+            .as_object()
+            .into_iter()
+            .flatten()
+            .map(|(key, value)| (key.to_string(), value.as_str().unwrap_or_default()));
+
+        let (key, value) = creds.next().unwrap();
+        assert_eq!(key, "AZURE_TENANT_ID");
+        assert_eq!(value, "tenant");
+
+        let (key, value) = creds.next().unwrap();
+        assert_eq!(key, "AZURE_CLIENT_ID");
+        assert_eq!(value, "client");
+
+        let (key, value) = creds.next().unwrap();
+        assert_eq!(key, "AZURE_CLIENT_SECRET");
+        assert_eq!(value, "secret");
+
+        assert!(creds.next().is_none());
+    }
 }
